@@ -13,7 +13,7 @@ import sys
 import static
 
 PORT = os.environ.get('PORT', 8000)
-STATIC_DIR = sys.argv[1]
+STATIC_DIR =  os.path.abspath(sys.argv[1])
 
 
 app = static.Cling(STATIC_DIR)
